==> root-ts-0.9.90.tgz: package/spec/route.ts <==
import { Route, APIRoute, PageRoute, MiddlewareRoute, Method, APIBase, DynamicResourceRoute, RouteServiceTemplate, APIServiceSpec } from "../lib/route"
import * as ServiceSpec from "./service"

export abstract class RouteService<T extends APIServiceSpec> extends RouteServiceTemplate<T>{
    dependencies = ["ExpressService", "MongodbService", "RouteSessionService"]
    services: ServiceSpec.AllServices
}


export namespace AccountAPIService {
    export const prefix = "/api/"
    export const name = "api.account"
    export const API = {
        getCurrentAccount: new class extends APIBase {
            readonly method = "POST"
            readonly path = "account/me/GET"
            info: {
                account: AccountService.Account
            }
            return: AccountService.Account
        },
        webLoginStandard: new class extends APIBase {
            readonly method = "POST"
            readonly path = "account/authentication/standard/GET"
            body: {
                // email or accountname
                login: string
                password: string
            }
            return: {
                account: AccountService.Account
            }
        },
        getTokenStandard: new class extends APIBase {
            readonly method = "POST"
            readonly path = "account/authentication/standard/token/GET"
            body: {
                // email or accountname
                login: string
                password: string
            }
            return: {
                account: AccountService.Account
                token: string
            }
        },
        // Creating a account will also create default workspace for him
        registerStandard: new class extends APIBase {
            readonly method = "POST"
            readonly path = "account/authentication/standard"
            body: {
                name: string
                password: string
                email: string
            }
            return: {
                account: AccountService.Account
            }
        },
    }
}

export abstract class AccountAPIServiceSpec extends RouteService<typeof AccountAPIService.API>{
    readonly name = "api.account"
    readonly dependencies = this.dependencies.concat(["AccountService", "AuthenticationService", "TTLSessionStorage"])
    services: ServiceSpec.AllServices
    constructor() {
        super(AccountAPIService)
    }
}

==> root-ts-0.10.3.tgz: package/spec/route.ts <==
import { Route, APIRoute, PageRoute, MiddlewareRoute, Method, APIBase, DynamicResourceRoute, RouteServiceTemplate, APIServiceSpec } from "../lib/route"
import * as ServiceSpec from "./service"

export abstract class RouteService<T extends APIServiceSpec> extends RouteServiceTemplate<T>{
    dependencies = ["ExpressService", "MongodbService", "RouteSessionService"]
    services: ServiceSpec.AllServices
}


export namespace AccountAPIServiceSpec {
    export const prefix = "/api/"
    export const name = "api.account"
    export const API = {
        getCurrentAccount: new class extends APIBase {
            readonly method = "POST"
            readonly path = "account/me/GET"
            info: {
                account: Type.Root.AccountService.Account
            }
            return: Type.Root.AccountService.Account
        },
        webLoginStandard: new class extends APIBase {
            readonly method = "POST"
            readonly path = "account/authentication/standard/GET"
            body: {
                // email or accountname
                login: string
                password: string
            }
            return: {
                account: Type.Root.AccountService.Account
            }
        },
        getTokenStandard: new class extends APIBase {
            readonly method = "POST"
            readonly path = "account/authentication/standard/token/GET"
            body: {
                // email or accountname
                login: string
                password: string
            }
            return: {
                account: Type.Root.AccountService.Account
                token: string
            }
        },
        // Creating a account will also create default workspace for him
        registerStandard: new class extends APIBase {
            readonly method = "POST"
            readonly path = "account/authentication/standard"
            body: {
                name: string
                password: string
                email: string
            }
            return: {
                account: Type.Root.AccountService.Account
            }
        },
    }
}

export abstract class AccountAPIService extends RouteService<typeof AccountAPIServiceSpec.API>{
    readonly name = "api.account"
    readonly dependencies = this.dependencies.concat(["AccountService", "AuthenticationService", "TTLSessionStorage"])
    services: ServiceSpec.AllServices
    constructor() {
        super(AccountAPIServiceSpec)
    }
}
